==> app_service-1.0.1.tar.gz: lib/src/maps/str_to_lang_enum_map.dart <==
import '../enums/language_enum.dart';

/// 语言字符串到语言枚举的映射关系
final Map<String, LanguageEnum> strToLangEnumMap = {
  'zh': LanguageEnum.zh, // 中文
  'zh_Hans': LanguageEnum.zhHans, // 简体中文
  'zh_Hant': LanguageEnum.zhHant, // 繁体中文
  'zh_HK': LanguageEnum.zhHk, // 中文（香港）
  'zh_TW': LanguageEnum.zhTw, // 中文（台湾）
  'ru': LanguageEnum.ru, // 俄语
  'de': LanguageEnum.de, // 德语
  'fr': LanguageEnum.fr, // 法语
  'ja': LanguageEnum.ja, // 日语
  'ko': LanguageEnum.ko, // 韩语
  'es': LanguageEnum.es, // 西班牙语
  'ar': LanguageEnum.ar, // 阿拉伯语
  'en': LanguageEnum.en, // 英语
  'US': LanguageEnum.enUs, // 英语（美国）
  'UK': LanguageEnum.enUk, // 英语（英国）
  'pt': LanguageEnum.pt, // 葡萄牙语
  'it': LanguageEnum.it, // 意大利语
  'nl': LanguageEnum.nl, // 荷兰语
  'tr': LanguageEnum.tr, // 土耳其语
  'hi': LanguageEnum.hi, // 印地语
  'id': LanguageEnum.id, // 印尼语
  'vi': LanguageEnum.vi, // 越南语
  'th': LanguageEnum.th, // 泰语
  'ms': LanguageEnum.ms, // 马来语
  'fil': LanguageEnum.fil, // 菲律宾语
  'sv': LanguageEnum.sv, // 瑞典语
  'pl': LanguageEnum.pl, // 波兰语
  'hu': LanguageEnum.hu, // 匈牙利语
  'ro': LanguageEnum.ro, // 罗马尼亚语
  'cs': LanguageEnum.cs, // 捷克语
  'el': LanguageEnum.el, // 希腊语
  'he': LanguageEnum.he, // 希伯来语
  'da': LanguageEnum.da, // 丹麦语
  'fi': LanguageEnum.fi, // 芬兰语
  'no': LanguageEnum.no, // 挪威语
  'sk': LanguageEnum.sk, // 斯洛伐克语
  'sl': LanguageEnum.sl, // 斯洛文尼亚语
  'bg': LanguageEnum.bg, // 保加利亚语
  'af': LanguageEnum.af, // 南非荷兰语
  'sq': LanguageEnum.sq, // 阿尔巴尼亚语
  'hy': LanguageEnum.hy, // 亚美尼亚语
  'az': LanguageEnum.az, // 阿塞拜疆语
  'eu': LanguageEnum.eu, // 巴斯克语
  'bn': LanguageEnum.bn, // 孟加拉语
  'bs': LanguageEnum.bs, // 波斯尼亚语
  'ca': LanguageEnum.ca, // 加泰罗尼亚语
  'hr': LanguageEnum.hr, // 克罗地亚语
  'cy': LanguageEnum.cy, // 威尔士语
  'et': LanguageEnum.et, // 爱沙尼亚语
  'tl': LanguageEnum.tl, // 菲律宾语
  'gl': LanguageEnum.gl, // 加利西亚语
  'ka': LanguageEnum.ka, // 格鲁吉亚语
  'gu': LanguageEnum.gu, // 古吉拉特语
  'ht': LanguageEnum.ht, // 海地克里奥尔语
  'ha': LanguageEnum.ha, // 豪萨语
  'haw': LanguageEnum.haw, // 夏威夷语
  'iw': LanguageEnum.iw, // 希伯来语
  'jw': LanguageEnum.jw, // 爪哇语
  'kk': LanguageEnum.kk, // 哈萨克语
  'km': LanguageEnum.km, // 高棉语
  'kn': LanguageEnum.kn, // 卡纳达语
  'ky': LanguageEnum.ky, // 吉尔吉斯语
  'lo': LanguageEnum.lo, // 老挝语
  'la': LanguageEnum.la, // 拉丁语
  'lv': LanguageEnum.lv, // 拉脱维亚语
  'lt': LanguageEnum.lt, // 立陶宛语
  'lb': LanguageEnum.lb, // 卢森堡语
  'mk': LanguageEnum.mk, // 马其顿语
  'mg': LanguageEnum.mg, // 马尔加什语
  'mt': LanguageEnum.mt, // 马耳他语
  'mi': LanguageEnum.mi, // 毛利语
  'mr': LanguageEnum.mr, // 马拉地语
  'mn': LanguageEnum.mn, // 蒙古语
  'ne': LanguageEnum.ne, // 尼泊尔语
  'ps': LanguageEnum.ps, // 普什图语
  'pa': LanguageEnum.pa, // 旁遮普语
  'qu': LanguageEnum.qu, // 凯楚亚语
  'gd': LanguageEnum.gd, // 苏格兰盖尔语
  'sr': LanguageEnum.sr, // 塞尔维亚语
  'st': LanguageEnum.st, // 塞索托语
  'sn': LanguageEnum.sn, // 修纳语
  'sd': LanguageEnum.sd, // 信德语
  'si': LanguageEnum.si, // 僧伽罗语
  'su': LanguageEnum.su, // 巽他语
  'sw': LanguageEnum.sw, // 斯瓦希里语
  'tg': LanguageEnum.tg, // 塔吉克语
  'ta': LanguageEnum.ta, // 泰米尔语
  'te': LanguageEnum.te, // 泰卢固语
  'ur': LanguageEnum.ur, // 乌尔都语
  'uz': LanguageEnum.uz, // 乌兹别克语
  'xh': LanguageEnum.xh, // 科萨语
  'yi': LanguageEnum.yi, // 意第绪语
  'zu': LanguageEnum.zu, // 祖鲁语
};

==> app_service-4.0.0.tar.gz: lib/src/maps/str_to_lang_enum_map.dart <==
import '../enums/language_enum.dart';

/// 语言字符串到语言枚举的映射关系
final Map<String, LanguageEnum> strToLangEnumMap = {
  'zh': LanguageEnum.zh, // 中文
  'zh-CN': LanguageEnum.zhCN, // 简体中文
  'zh-MO': LanguageEnum.zhMO, // 中文（澳门）
  'zh-HK': LanguageEnum.zhHk, // 中文（香港）
  'zh-TW': LanguageEnum.zhTW, // 中文（台湾）
  'ru': LanguageEnum.ru, // 俄语
  'ru-RU': LanguageEnum.ruRU, // 俄语（俄罗斯）
  'ru-BY': LanguageEnum.ruBY, // 俄语（白俄罗斯）
  'ru-KZ': LanguageEnum.ruKZ, // 俄语（哈萨克斯坦）
  'ru-UA': LanguageEnum.ruUA, // 俄语（乌克兰）
  'uk': LanguageEnum.uk, // 乌克兰
  'kk': LanguageEnum.kk, // 哈萨克斯坦
  'be': LanguageEnum.be, // 白俄罗斯
  'sr': LanguageEnum.sr, // 塞尔维亚
  'de': LanguageEnum.de, // 德语
  'fr': LanguageEnum.fr, // 法语
  'ja': LanguageEnum.ja, // 日语
  'ko': LanguageEnum.ko, // 韩语
  'es': LanguageEnum.es, // 西班牙语
  'ar': LanguageEnum.ar, // 阿拉伯语
  'en': LanguageEnum.en, // 英语
  'en-US': LanguageEnum.enUS, // 英语（美国）
  'en-GB': LanguageEnum.enUK, // 英语（英国）
  'en-AU': LanguageEnum.enAU, // 英语（印度）
  'en-IN': LanguageEnum.enIN, // 英语（印度）
  'pt': LanguageEnum.pt, // 葡萄牙语
  'it': LanguageEnum.it, // 意大利语
  'nl': LanguageEnum.nl, // 荷兰语
  'tr': LanguageEnum.tr, // 土耳其语
  'hi': LanguageEnum.hi, // 印地语
  'id': LanguageEnum.id, // 印尼语
  'vi': LanguageEnum.vi, // 越南语
  'th': LanguageEnum.th, // 泰语
  'ms': LanguageEnum.ms, // 马来语
  'fil': LanguageEnum.fil, // 菲律宾语
  'sv': LanguageEnum.sv, // 瑞典语
  'pl': LanguageEnum.pl, // 波兰语
  'hu': LanguageEnum.hu, // 匈牙利语
  'ro': LanguageEnum.ro, // 罗马尼亚语
  'cs': LanguageEnum.cs, // 捷克语
  'el': LanguageEnum.el, // 希腊语
  'he': LanguageEnum.he, // 希伯来语
  'da': LanguageEnum.da, // 丹麦语
  'fi': LanguageEnum.fi, // 芬兰语
  'no': LanguageEnum.no, // 挪威语
  'sk': LanguageEnum.sk, // 斯洛伐克语
  'sl': LanguageEnum.sl, // 斯洛文尼亚语
  'bg': LanguageEnum.bg, // 保加利亚语
  'af': LanguageEnum.af, // 南非荷兰语
  'sq': LanguageEnum.sq, // 阿尔巴尼亚语
  'hy': LanguageEnum.hy, // 亚美尼亚语
  'az': LanguageEnum.az, // 阿塞拜疆语
  'eu': LanguageEnum.eu, // 巴斯克语
  'bn': LanguageEnum.bn, // 孟加拉语
  'bs': LanguageEnum.bs, // 波斯尼亚语
  'ca': LanguageEnum.ca, // 加泰罗尼亚语
  'hr': LanguageEnum.hr, // 克罗地亚语
  'cy': LanguageEnum.cy, // 威尔士语
  'et': LanguageEnum.et, // 爱沙尼亚语
  'tl': LanguageEnum.tl, // 菲律宾语
  'gl': LanguageEnum.gl, // 加利西亚语
  'ka': LanguageEnum.ka, // 格鲁吉亚语
  'gu': LanguageEnum.gu, // 古吉拉特语
  'ht': LanguageEnum.ht, // 海地克里奥尔语
  'ha': LanguageEnum.ha, // 豪萨语
  'haw': LanguageEnum.haw, // 夏威夷语
  'iw': LanguageEnum.iw, // 希伯来语
  'jw': LanguageEnum.jw, // 爪哇语
  'km': LanguageEnum.km, // 高棉语
  'kn': LanguageEnum.kn, // 卡纳达语
  'ky': LanguageEnum.ky, // 吉尔吉斯语
  'lo': LanguageEnum.lo, // 老挝语
  'la': LanguageEnum.la, // 拉丁语
  'lv': LanguageEnum.lv, // 拉脱维亚语
  'lt': LanguageEnum.lt, // 立陶宛语
  'lb': LanguageEnum.lb, // 卢森堡语
  'mk': LanguageEnum.mk, // 马其顿语
  'mg': LanguageEnum.mg, // 马尔加什语
  'mt': LanguageEnum.mt, // 马耳他语
  'mi': LanguageEnum.mi, // 毛利语
  'mr': LanguageEnum.mr, // 马拉地语
  'mn': LanguageEnum.mn, // 蒙古语
  'ne': LanguageEnum.ne, // 尼泊尔语
  'ps': LanguageEnum.ps, // 普什图语
  'pa': LanguageEnum.pa, // 旁遮普语
  'qu': LanguageEnum.qu, // 凯楚亚语
  'gd': LanguageEnum.gd, // 苏格兰盖尔语
  'st': LanguageEnum.st, // 塞索托语
  'sn': LanguageEnum.sn, // 修纳语
  'sd': LanguageEnum.sd, // 信德语
  'si': LanguageEnum.si, // 僧伽罗语
  'su': LanguageEnum.su, // 巽他语
  'sw': LanguageEnum.sw, // 斯瓦希里语
  'tg': LanguageEnum.tg, // 塔吉克语
  'ta': LanguageEnum.ta, // 泰米尔语
  'te': LanguageEnum.te, // 泰卢固语
  'ur': LanguageEnum.ur, // 乌尔都语
  'uz': LanguageEnum.uz, // 乌兹别克语
  'xh': LanguageEnum.xh, // 科萨语
  'yi': LanguageEnum.yi, // 意第绪语
  'zu': LanguageEnum.zu, // 祖鲁语
};
